"use strict";

var _react = require("react");

var _react2 = _interopRequireDefault(_react);

var _enzyme = require("enzyme");

var _enzyme2 = _interopRequireDefault(_enzyme);

var _enzymeAdapterReact = require("enzyme-adapter-react-16");

var _enzymeAdapterReact2 = _interopRequireDefault(_enzymeAdapterReact);

var _Form = require("./Form");

var _Form2 = _interopRequireDefault(_Form);

var _FormFragment = require("./FormFragment");

var _FormFragment2 = _interopRequireDefault(_FormFragment);

var _FormContext = require("./FormContext");

var _FormContext2 = _interopRequireDefault(_FormContext);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_enzyme2.default.configure({ adapter: new _enzymeAdapterReact2.default() });

describe("Context", function () {
  var onFormChange = jest.fn();
  var singleField = [{
    id: "FIELD1",
    name: "prop1",
    defaultValue: "test",
    type: "text"
  }];

  test("provides value", function () {
    var propValue = { prop1: "value1" };
    var value = void 0;
    var form = (0, _enzyme.mount)(_react2.default.createElement(
      _Form2.default,
      {
        defaultFields: singleField,
        onChange: onFormChange,
        value: propValue
      },
      _react2.default.createElement(
        _FormContext2.default.Consumer,
        null,
        function (context) {
          expect(context.value).toEqual(propValue);
        }
      )
    ));
    expect(form.state().value).toEqual(propValue);
  });

  test("FormFragment has the correct value", function () {
    var propValue = { prop1: "value1" };
    var value = void 0;
    var form = (0, _enzyme.mount)(_react2.default.createElement(
      _Form2.default,
      { onChange: onFormChange, value: propValue },
      _react2.default.createElement(_FormFragment2.default, { defaultFields: singleField })
    ));
    expect(form.state().value).toEqual(propValue);
  });

  test("FormFragment has the correct value after props update", function () {
    var propValue = { prop1: "value1" };
    var value = void 0;
    var form = (0, _enzyme.mount)(_react2.default.createElement(
      _Form2.default,
      { onChange: onFormChange, value: propValue },
      _react2.default.createElement(_FormFragment2.default, { defaultFields: singleField })
    ));
    expect(form.state().value.prop1).toEqual("value1");

    form.setProps({ value: { prop1: "value2" } });
    expect(form.state().value.prop1).toEqual("value2");
  });
});