"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var findFieldsToCompareTo = exports.findFieldsToCompareTo = function findFieldsToCompareTo(fieldsToFind, allFields) {
  var targetFields = [];

  typeof fieldsToFind.forEach === "function" && fieldsToFind.forEach(function (targetField) {
    var target = allFields.find(function (currField) {
      return targetField === currField.id;
    });
    if (!target) {
      console.warn("Could not find field " + targetField + " to compare against");
    } else {
      targetFields.push(target);
    }
  });

  return targetFields;
};

var isBigger = exports.isBigger = function isBigger(value, comparedTo) {
  return compareSize(value, comparedTo, "BIGGER");
};

var isSmaller = exports.isSmaller = function isSmaller(value, comparedTo) {
  return compareSize(value, comparedTo, "SMALLER");
};

var compareSize = exports.compareSize = function compareSize(value, comparedTo, type) {
  var targetValue = parseFloat(value);
  var compareValue = parseFloat(comparedTo.value);
  if (targetValue === NaN || compareValue === NaN) {
    return false;
  } else if (type === "BIGGER") {
    return targetValue > compareValue;
  } else {
    return targetValue < compareValue;
  }
};

var isLonger = exports.isLonger = function isLonger(value, comparedTo) {
  return compareLength(value, comparedTo, "LONGER");
};
var isShorter = exports.isShorter = function isShorter(value, comparedTo) {
  return compareLength(value, comparedTo, "SHORTER");
};

var compareLength = exports.compareLength = function compareLength(value, comparedTo, type) {
  var valueLength = value ? value.toString().length : undefined;
  var compareLength = comparedTo.value ? comparedTo.value.toString().length : undefined;
  if (valueLength === undefined || compareLength === undefined) {
    return false;
  } else if (type === "LONGER") {
    return valueLength > compareLength;
  } else {
    return valueLength < compareLength;
  }
};

var comparedTo = exports.comparedTo = function comparedTo(_ref) {
  var value = _ref.value,
      _ref$fields = _ref.fields,
      fields = _ref$fields === undefined ? [] : _ref$fields,
      _ref$allFields = _ref.allFields,
      allFields = _ref$allFields === undefined ? [] : _ref$allFields,
      _ref$is = _ref.is,
      is = _ref$is === undefined ? "BIGGER" : _ref$is,
      message = _ref.message;

  var targetFields = findFieldsToCompareTo(fields, allFields);

  switch (is) {
    case "BIGGER":
      {
        return targetFields.every(function (targetField) {
          return isBigger(value, targetField);
        }) ? undefined : message || "Not the biggest field";
      }

    case "SMALLER":
      {
        return targetFields.every(function (targetField) {
          return isSmaller(value, targetField);
        }) ? undefined : message || "Not the smallest field";
      }

    case "LONGER":
      {
        return targetFields.every(function (targetField) {
          return isLonger(value, targetField);
        }) ? undefined : message || "Not the longer field";
      }

    case "SHORTER":
      {
        return targetFields.every(function (targetField) {
          return isShorter(value, targetField);
        }) ? undefined : message || "Not the shortest field";
      }

    default:
      return;
  }
};

var lengthIsGreaterThan = exports.lengthIsGreaterThan = function lengthIsGreaterThan(_ref2) {
  var value = _ref2.value,
      length = _ref2.length,
      message = _ref2.message;

  if (isNaN(length) || (value || "").length > length) {
    return;
  } else {
    return message || "Should have more than " + length + " characters";
  }
};

var lengthIsLessThan = exports.lengthIsLessThan = function lengthIsLessThan(_ref3) {
  var value = _ref3.value,
      length = _ref3.length,
      message = _ref3.message;

  if (isNaN(length) || (value || "").length < length) {
    return;
  } else {
    return message || "Should have more than " + length + " characters";
  }
};

// TODO: Consider option for inverting rule...
var matchesRegEx = exports.matchesRegEx = function matchesRegEx(_ref4) {
  var value = _ref4.value,
      _ref4$pattern = _ref4.pattern,
      pattern = _ref4$pattern === undefined ? ".*" : _ref4$pattern,
      message = _ref4.message;

  var regExObj = new RegExp(pattern);
  if (!regExObj.test(value)) {
    return message || "Invalid input provided"; // <= Terrible message!
  }
};

var getDefaultNumericalRangeErrorMessages = exports.getDefaultNumericalRangeErrorMessages = function getDefaultNumericalRangeErrorMessages(min, max) {
  if (typeof min !== "undefined" && typeof max !== "undefined") {
    return "Value cannot be less than " + min + " or greater than " + max;
  } else if (typeof min !== "undefined") {
    return "Value cannot be less than " + min;
  } else if (typeof max !== "undefined") {
    return "Value cannot be greater than " + max;
  }
};

var fallsWithinNumericalRange = exports.fallsWithinNumericalRange = function fallsWithinNumericalRange(_ref5) {
  var value = _ref5.value,
      min = _ref5.min,
      max = _ref5.max,
      required = _ref5.required,
      message = _ref5.message;

  var parsedValue = parseFloat(value);
  if (isNaN(parsedValue)) {
    return message || "Value must be a number";
  }
  if (typeof min !== "undefined" && value < min) {
    return message || getDefaultNumericalRangeErrorMessages(min, max);
  }
  if (typeof max !== "undefined" && value > max) {
    return message || getDefaultNumericalRangeErrorMessages(min, max);
  }
};

var validators = exports.validators = {
  lengthIsGreaterThan: lengthIsGreaterThan,
  lengthIsLessThan: lengthIsLessThan,
  matchesRegEx: matchesRegEx,
  fallsWithinNumericalRange: fallsWithinNumericalRange,
  comparedTo: comparedTo
};

var validateField = exports.validateField = function validateField(field, fields, validationHandler, parentContext) {
  var required = field.required,
      visible = field.visible,
      value = field.value,
      _field$validWhen = field.validWhen,
      validWhen = _field$validWhen === undefined ? {} : _field$validWhen;

  var isValid = true;
  var errorMessages = [];
  if (visible) {
    if (required) {
      var valueIsEmptyArray = Array.isArray(value) && value.length === 0;
      isValid = (value || value === 0 || value === false) && !valueIsEmptyArray;
    }

    isValid = Object.keys(validWhen).reduce(function (allValidatorsPass, validator) {
      if (typeof validators[validator] === "function") {
        var validationConfig = _extends({}, validWhen[validator], {
          value: value,
          allFields: fields
        });

        var _message = validators[validator](validationConfig);
        if (_message) {
          allValidatorsPass = false;
          errorMessages.push(_message);
        }
      } else {
        console.warn("The requested validator does not exist", validator);
      }

      return allValidatorsPass;
    }, isValid) && isValid;
  }
  if (validationHandler) {
    var _message2 = validationHandler(field, fields, parentContext);
    if (_message2) {
      isValid = false;
      errorMessages.push(_message2);
    }
  }
  return Object.assign({}, field, {
    isValid: isValid,
    errorMessages: errorMessages.join(", ")
  });
};

var validateAllFields = exports.validateAllFields = function validateAllFields(fields, validationHandler, parentContext) {
  var validatedFields = fields.map(function (field) {
    return validateField(field, fields, validationHandler, parentContext);
  });
  return validatedFields;
};